@@ -63,7 +63,9 @@ class BlockDisplayControlAdmin(admin.ModelAdmin):
         return _('All Page')
         
     def display2(self, obj):
-        return obj.display
+        if obj.display:
+            return _("True")
+        return _("False")
         
     def useGlobalBlockDisplayControl2(self, obj):
         if obj.useGlobalBlockDisplayControl:
