@@ -34,9 +34,10 @@ class FanPage(object):
         self.url = url
         
 class Photo(object):
-    def __init__(self, name, url):
+    def __init__(self, name, url, link):
         self.name = name
         self.url = url
+        self.link = link
         
 def getFanPageId(accessToken, url):
     # get fan page id
@@ -138,7 +139,7 @@ class FacebookPhotoPlugin(CMSPluginBase):
                           u'?tab=album&album_id=xxx'),
             })
             return context
-        query = "?fields=photos.limit(100){name,images}"
+        query = "?fields=photos.limit(100){name,images,link}"
         req = requests.get(
             'https://graph.facebook.com/v2.8/%s/%s&access_token=%s' % (
             albumId, query, accessToken)
@@ -161,6 +162,7 @@ class FacebookPhotoPlugin(CMSPluginBase):
         for data in content:
             name = None
             url = None
+            link = None
             if not 'images' in data:
                 continue
             for data2 in data['images']:
@@ -169,7 +171,9 @@ class FacebookPhotoPlugin(CMSPluginBase):
                     break
             if 'name' in data:
                 name = mark_safe(data['name'].replace('\n', '<br />'))
-            photoList.append(Photo(name, url))
+            if 'link' in data:
+                link = data['link']
+            photoList.append(Photo(name, url, link))
             if len(photoList) == instance.limit:
                 break
         
